# pokemon_tcg_collection_manager
A cli tool/library to manage, store and analyze a pokemon card collection
## Prerequisits:
* python3.10 or greater
* pip3 in path
* python3.10 in path
## Installation:
* run `pip3 install pokemonCardLogger` 
* or download zip and run `python3 setup.py install` in the directory you unzipped the zip file
## Use as a library:
* `from pokemonCardLogger import clss_pickle as pcl` or `from pokemonCardLogger import clss_json as pcl`
## Use as a program
* zipped install version is required
* in the install directory, run `python3 pokemonCardLogger/main.py` for unix/mac or `python3 pokemonCardLogger\main.py` for windows
